# frics

[![PyPI - Version](https://img.shields.io/pypi/v/frics.svg)](https://pypi.org/project/frics)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/frics.svg)](https://pypi.org/project/frics)


Frics is a Textual TUI app to search, view, and copy code from [Frida Codeshare](https://codeshare.frida.re/). A local copy of the database is created to speed up search. Searches are performed against the project name, author, description, and even the source code itself, making this a great tool for a quick reference.



-----

## Installation

Installation is recommended using [pipx](https://pypa.github.io/pipx/).

```console
pipx install frics
```

## Screenshot
![Screenshot1](https://github.com/daddycocoaman/frics/blob/main/docs/screenshot1.png?raw=True)

## License

`frics` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
